@@ -1,10 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import json
+import urllib
 import lxml.html
 
 __title__   = 'coinmarketcap'
-__version__ = '0.3'
+__version__ = '0.4'
 __author__  = '@c0ding'
 __repo__    = 'https://github.com/c0ding/coinmarketcap-api'
 __license__ = 'Apache v2.0 License'
@@ -14,7 +16,8 @@ ENTRY_POINT_URL = 'http://coinmarketcap.com/all.html'
 def coin_info(PARAMETER):
 	raw_data = lxml.html.parse(ENTRY_POINT_URL)
 	tree = raw_data.xpath('//tr[@id="id-' + PARAMETER + '"]/td//text()')
-	coin_details = [x for x in tree if x != ' ']
+	clean_space = map(lambda x: x.strip(), tree)
+	coin_details = [x for x in clean_space if x]
 	return coin_details
 
 
@@ -30,7 +33,7 @@ def market_cap_info():
 	return market_cap_details
 
 
-def total_currencies_info():
-	raw_data = lxml.html.parse(ENTRY_POINT_URL)
-	total_currencies_details = raw_data.xpath("//div[@class='pull-right small']//text()")
-	return total_currencies_details[0]
+def coinmarketcap_info():
+	raw_data = urllib.urlopen('http://coinmarketcap.com/static/generated_pages/global/stats.json')
+	coinmarketcap_details = json.load(raw_data)
+	return coinmarketcap_details
